@@ -1,3 +1,6 @@
+import asyncio
+
+from django.utils.translation import get_language
 from rest_framework.request import Request
 from rest_framework.response import Response
 
@@ -21,7 +24,7 @@ class HTTPMethod(Protocol):
     ignored_patch_params: Set[str]
     ignored_delete_params: Set[str]
 
-    def _process_request(self, data: DataDict) -> Response:
+    async def process_request(self, data: DataDict, lang: str) -> Response:
         """Process request"""
 
 
@@ -34,7 +37,7 @@ class GetMixin:
     def get(self: HTTPMethod, request: Request, *args: Any, **kwargs: Any) -> Response:  # pylint: disable=W0613
         params = {k: v for k, v in request.query_params.items() if k not in self.ignored_get_params}
         kwargs.update(params)
-        return self._process_request(data=kwargs)
+        return asyncio.run(self.process_request(data=kwargs, lang=get_language()))
 
 
 class PostMixin:
@@ -46,7 +49,7 @@ class PostMixin:
     def post(self: HTTPMethod, request: Request, *args: Any, **kwargs: Any) -> Response:  # pylint: disable=W0613
         params = {k: v for k, v in request.data.items() if k not in self.ignored_post_params}
         kwargs.update(params)
-        return self._process_request(data=kwargs)
+        return asyncio.run(self.process_request(data=kwargs, lang=get_language()))
 
 
 class PutMixin:
@@ -58,7 +61,7 @@ class PutMixin:
     def put(self: HTTPMethod, request: Request, *args: Any, **kwargs: Any) -> Response:  # pylint: disable=W0613
         params = {k: v for k, v in request.data.items() if k not in self.ignored_put_params}
         kwargs.update(params)
-        return self._process_request(data=kwargs)
+        return asyncio.run(self.process_request(data=kwargs, lang=get_language()))
 
 
 class PatchMixin:
@@ -70,7 +73,7 @@ class PatchMixin:
     def patch(self: HTTPMethod, request: Request, *args: Any, **kwargs: Any) -> Response:  # pylint: disable=W0613
         params = {k: v for k, v in request.data.items() if k not in self.ignored_patch_params}
         kwargs.update(params)
-        return self._process_request(data=kwargs)
+        return asyncio.run(self.process_request(data=kwargs, lang=get_language()))
 
 
 class DeleteMixin:
@@ -82,4 +85,4 @@ class DeleteMixin:
     def delete(self: HTTPMethod, request: Request, *args: Any, **kwargs: Any) -> Response:  # pylint: disable=W0613
         params = {k: v for k, v in request.data.items() if k not in self.ignored_delete_params}
         kwargs.update(params)
-        return self._process_request(data=kwargs)
+        return asyncio.run(self.process_request(data=kwargs, lang=get_language()))
